@@ -15,4 +15,11 @@ from shrinkage import shrink
 
 from edf import makeedf
 
-from kde import fitkde
\ No newline at end of file
+from kde import fitkde
+
+from ecdfgof import kstest
+from ecdfgof import adtest
+from ecdfgof import cvmtest
+
+from distfit import fit
+from distfit import compare
